@@ -3,9 +3,6 @@ import datetime
 from app import app
 from modules.box__default.auth.models import User
 
-SEP_CHAR = "#"
-SEP_NUM = 23
-
 
 def add_admin(email, password):
     with app.app_context():
@@ -18,12 +15,12 @@ def add_admin(email, password):
         user.save()
 
 
-def upload():
+def upload(verbose=False):
     with open("config.json", "r") as config:
         config = json.load(config)
-        print("Initialising User")
-        print(SEP_CHAR * SEP_NUM, end="\n\n")
-        print("Adding Admin ...")
         add_admin(
             config["admin_user"]["email"], config["admin_user"]["password"]
         )
+
+        if verbose:
+            print("[x] Added Admin User")
