@@ -3,9 +3,6 @@ from app import app
 from init import db
 from modules.box__default.settings.models import Settings
 
-SEP_CHAR = "#"
-SEP_NUM = 23
-
 
 def add_setting(name, value):
     with app.app_context():
@@ -19,11 +16,11 @@ def add_setting(name, value):
             db.session.commit()
 
 
-def upload():
+def upload(verbose=False):
     with open("config.json", "r") as config:
         config = json.load(config)
-        print("Initialising Settings")
-        print(SEP_CHAR * SEP_NUM, end="\n\n")
-        print("Adding Dummy Settings ...")
         for name, value in config["settings"].items():
             add_setting(name, value)
+
+        if verbose:
+            print("[x] Added Dummy Settings")
