@@ -1,6 +1,6 @@
 import datetime
 
-from shopyoapi.init import db
+from init import db
 
 
 class Image(db.Model):
@@ -32,7 +32,7 @@ class Image(db.Model):
         db.session.delete(self)
         db.session.commit()
 
-    def getImage(image_id):
+    def getImage(self, image_id):
         return Images.query.filter_by(id=image_id).first()
 
 
@@ -46,9 +46,6 @@ class Resource(db.Model):
     created_date = db.Column(
         db.DateTime, default=datetime.datetime.now(), nullable=False
     )
-    product_barcode = db.Column(db.String(100), db.ForeignKey("product.barcode"))
-    category_name = db.Column(db.String(100), db.ForeignKey("categories.name"))
-    subcategory_name = db.Column(db.String(100), db.ForeignKey("subcategories.name"))
 
     def set_hash(self, password):
         self.password = generate_password_hash(password, method="sha256")
